"""Access bee flight forecast information published by Deutscher Wetterdienst (DWD)"""
__appname__ = "apicast"
__version__ = "0.8.0"
